import { DeepClientInstance, SerialOperation } from '@deep-foundation/deeplinks/imports/client.js';
import { DeviceInfo } from './device-info.js';
import { Link } from '@deep-foundation/deeplinks/imports/minilinks.js';
import { DeviceDecorator } from './create-device-decorator.js';
/**
  * Gets serial operations to insert Device
  *
  * @example
 ```ts
 const serialOperations = await getDeviceValueInsertSerialOperations({
   deep
 });
 await deep.serial({
   operations: serialOperations
 })
 ```
  */
export declare function makeDeviceValueUpdateOperations<TDeepClient extends DeepClientInstance>(this: DeviceDecorator<TDeepClient>, options: MakeDeviceValueUpdateSerialOperationsOptions): Promise<Array<SerialOperation>>;
export type MakeDeviceValueUpdateSerialOperationsOptions = {
    /**
     * Device Info
     *
     * @remarks
     * If not passed then {@link getAllDeviceInfo} is used to get the device info
     */
    info?: DeviceInfo;
} & ({
    /**
     * Device Link Id
     */
    deviceLinkId: number;
} | {
    /**
     * Device Link
     */
    deviceLink: Link<number>;
});
